@@ -3,7 +3,6 @@
 """md2po command line interface."""
 
 import argparse
-import io
 import sys
 try:
     from itertools import izip
@@ -26,9 +25,8 @@ def build_parser():
                         version='%(prog)s ' + __version__,
                         help='Show program version number and exit.')
     parser.add_argument('-q', '--quiet', action='store_true',
-                        help='Don\'t print output to STDOUT.')
+                        help='Do not print output to STDOUT.')
     parser.add_argument('glob_or_content', metavar='GLOB_OR_CONTENT',
-                        nargs='?', default=sys.stdin,
                         help='Glob to markdown input files or markdown'
                              ' content as a string. If not provided,'
                              ' will be read from STDIN.')
@@ -37,7 +35,8 @@ def build_parser():
                              ' ``GLOB_OR_CONTENT`` argument is a glob,'
                              ' as a list of comma separated values.',
                         metavar='PATH_1,PATH_2...')
-    parser.add_argument('-f', '--filepath', dest='po_filepath', default=None,
+    parser.add_argument('-po', '--po-filepath', dest='po_filepath',
+                        default=None,
                         help='Merge new msgids in the po file indicated'
                              ' at this parameter (if ``--save`` argument'
                              ' is passed) or use the msgids of the file'
@@ -47,11 +46,11 @@ def build_parser():
     parser.add_argument('-s', '--save', dest='save', action='store_true',
                         help='Save new found msgids to the po file'
                              ' indicated as parameter ``--filepath``.')
-    parser.add_argument('-m', '--markuptext', dest='markuptext',
+    parser.add_argument('-p', '--plaintext', dest='plaintext',
                         action='store_true',
-                        help='Include markdown markup characters in'
-                             ' extracted msgids for **bold text**,'
-                             ' *italic text*, `inline code` and `[links]`.')
+                        help='Do not include markdown markup characters in'
+                             ' extracted msgids for **bold text**, *italic'
+                             ' text*, `inline code` and [link](target).')
     parser.add_argument('-w', '--wrapwidth', dest='wrapwidth',
                         help='Wrap width for po file indicated at'
                              ' ``--filepath`` parameter. Only useful when'
@@ -63,7 +62,7 @@ def build_parser():
                         help='Mark new found msgids not present in the '
                              ' pofile passed at ``--filepath`` parameter'
                              ' as obsolete translations.')
-    parser.add_argument('-F', '--flags',
+    parser.add_argument('-f', '--flags',
                         default=DEFAULT_MD4C_FLAGS, dest='flags',
                         help='md4c extensions used to parse markdown'
                              ' content, separated by ``|`` or ``+``'
@@ -75,20 +74,20 @@ def build_parser():
     parser.add_argument('-x', '--xheaders', dest='xheaders',
                         action='store_true',
                         help='Include mdpo specification x-headers.'
-                             ' These only will be included if you pass the'
-                             ' parameter ``--markuptext``.')
+                             ' These only will be included if you do not pass'
+                             ' the parameter ``--plaintext``.')
     return parser
 
 
-def parse_options(args):
+def parse_options(args=[]):
     parser = build_parser()
-    if '-h' in sys.argv or '--help' in sys.argv:
+    if '-h' in args or '--help' in args:
         parser.print_help()
         sys.exit(0)
-    opts = parser.parse_args(args)
+    opts, unknown = parser.parse_known_args(args)
 
-    if isinstance(opts.glob_or_content, io.TextIOWrapper):
-        opts.glob_or_content = opts.glob_or_content.read().strip('\n')
+    if not sys.stdin.isatty():
+        opts.glob_or_content = sys.stdin.read().strip('\n')
     if opts.ignore:
         opts.ignore = parse_list_argument(opts.ignore)
 
@@ -102,7 +101,7 @@ def run(args=[]):
         po_filepath=opts.po_filepath,
         ignore=opts.ignore,
         save=opts.save,
-        plaintext=not opts.markuptext,
+        plaintext=opts.plaintext,
         mark_not_found_as_absolete=opts.mark_not_found_as_absolete,
         flags=opts.flags,
         encoding=opts.encoding,
@@ -118,5 +117,9 @@ def run(args=[]):
     return (pofile, 0)
 
 
-if __name__ == '__main__':
+def main():
     sys.exit(run(args=sys.argv[1:])[1])
+
+
+if __name__ == '__main__':
+    main()
